pub struct AddressUtxos {
utxos: BTreeMap<OutputLocation, Output>,
tx_ids: BTreeMap<TransactionLocation, Hash>,
network: Network,
last_height_and_hash: Option<(Height, Hash)>,
}Expand description
A convenience wrapper that efficiently stores unspent transparent outputs, and the corresponding transaction IDs.
Fields
utxos: BTreeMap<OutputLocation, Output>A set of unspent transparent outputs.
tx_ids: BTreeMap<TransactionLocation, Hash>The transaction IDs for each OutputLocation in utxos.
network: NetworkThe configured network for this state.
last_height_and_hash: Option<(Height, Hash)>The last height and hash that was queried to produce these UTXOs, if any. It will be None if the state is empty.
Implementations
Sourceimpl AddressUtxos
Auto-generated by derive_getters::Getters.
impl AddressUtxos
Auto-generated by derive_getters::Getters.
Sourcepub fn last_height_and_hash(&self) -> &Option<(Height, Hash)>
pub fn last_height_and_hash(&self) -> &Option<(Height, Hash)>
The last height and hash that was queried to produce these UTXOs, if any. It will be None if the state is empty.
Sourceimpl AddressUtxos
impl AddressUtxos